@@ -32,8 +32,8 @@ class QueryHandler():
         self.chain_query = db.shelf(shelf)
         self.queries = queries
 
-    def apply(self, func):
-        self.chain_query = self.chain_query.apply(func)
+    def add(self, data):
+        self.chain_query = self.chain_query.add(data)
         return self
 
     def count(self):
@@ -60,6 +60,7 @@ class QueryHandler():
         self.chain_query = self.chain_query.get(id_)
         return self
 
+    # Deprecated
     def insert(self, data):
         self.chain_query = self.chain_query.insert(data)
         return self
@@ -68,6 +69,10 @@ class QueryHandler():
         self.chain_query = self.chain_query.map(fn)
         return self
 
+    def patch(self, args):
+        self.chain_query = self.chain_query.patch(*args)
+        return self
+
     def put(self, args):
         self.chain_query = self.chain_query.put(*args)
         return self
